-- CONFIG
local vuf = {}
vuf.scale     = 1.00   -- Set frame scale
vuf.position  = true   -- Set frame position
vuf.player    = { "CENTER", UIParent, "CENTER", -280, -180 }  
vuf.target    = { "CENTER", UIParent, "CENTER", 280, -180 }   
vuf.colors    = true   -- Class colors for health bar
vuf.rest      = true   -- Turn off rest flashing and rest icon
vuf.combat    = true   -- Turn off combat flashing
vuf.combati   = false  -- Hide combat icon
vuf.rcolor    = true   -- Remove reaction color from target frame
vuf.dark      = true   -- Make frames darker
vuf.frameRgb  = { 0.4, 0.4, 0.4, 1 }  -- Set frame darkness
vuf.gpal      = true  -- Change Paladin class color from pink to gold
vuf.bsham     = true  -- Change Shaman class color from pink to blue
vuf.gdru      = false  -- Change Druid class color from orange to evoker green
vuf.ci        = false  -- Show class icons for all classes, set to false to show by class
vuf.cidruid   = false  -- Show class icon for Druid
vuf.cihunter  = false  -- Show class icon for Hunter
vuf.cimage    = false  -- Show class icon for Mage
vuf.cipaladin = false  -- Show class icon for Paladin
vuf.cipriest  = false  -- Show class icon for Priest
vuf.cirogue   = false  -- Show class icon for Rogue
vuf.cishaman  = false  -- Show class icon for Shaman
vuf.ciwarlock = false  -- Show class icon for Warlock
vuf.ciwarrior = false  -- Show class icon for Warrior


-- SCALE
PlayerFrame:SetScale(vuf.scale)
TargetFrame:SetScale(vuf.scale)
CastingBarFrame:SetScale(vuf.scale)


-- POSITION
if vuf.position then
    local function ApplyPosition()
        PlayerFrame_ResetUserPlacedPosition()
        TargetFrame_ResetUserPlacedPosition()

        PlayerFrame:ClearAllPoints()
        PlayerFrame:SetPoint(unpack(vuf.player))
        PlayerFrame:SetUserPlaced(true)

        TargetFrame:ClearAllPoints()
        TargetFrame:SetPoint(unpack(vuf.target))
        TargetFrame:SetUserPlaced(true)
    end

    local enteringWorld = CreateFrame("Frame")
    enteringWorld:RegisterEvent("PLAYER_ENTERING_WORLD")
    enteringWorld:SetScript("OnEvent", ApplyPosition)
end


-- CLASS COLORS
if vuf.colors then
    local function colour(statusbar, unit)
        local _, class, c
        if UnitIsPlayer(unit) and UnitIsConnected(unit) and unit == statusbar.unit and UnitClass(unit) then
                _, class = UnitClass(unit)
                c = CUSTOM_CLASS_COLORS and CUSTOM_CLASS_COLORS[class] or RAID_CLASS_COLORS[class]
                statusbar:SetStatusBarColor(c.r, c.g, c.b)
                --PlayerFrameHealthBar:SetStatusBarColor(0,1,0)
        end
    end

    hooksecurefunc("UnitFrameHealthBar_Update", colour)
    hooksecurefunc("HealthBar_OnValueChanged", function(self)
        colour(self, self.unit)
    end)
end


-- STOP REST FLASH
if vuf.rest then
    hooksecurefunc("PlayerFrame_UpdateStatus", function()
       if IsResting("player") then
          PlayerStatusTexture:Hide()
          PlayerRestGlow:Hide()
          PlayerStatusGlow:Hide()
          PlayerRestIcon:Hide()
       end
    end)
end

-- STOP COMBAT FLASH
if vuf.combat then
    hooksecurefunc("PlayerFrame_UpdateStatus", function()
       if PlayerFrame.inCombat then
          PlayerStatusTexture:Hide()
	  PlayerAttackGlow:Hide()
      	  PlayerStatusGlow:Hide()
       end
    end)
end

-- HIDE COMBAT ICON
if vuf.combati then
    hooksecurefunc("PlayerFrame_UpdateStatus", function()
     	  PlayerAttackIcon:Hide()
     	  PlayerAttackBackground:Hide()
    end)
end


-- SET TARGET REACTION COLOR
if vuf.rcolor then
    hooksecurefunc("TargetFrame_CheckFaction", function(self)
        self.nameBackground:SetVertexColor(0, 0, 0, 0.5);
    end)
end


-- DARK FRAMES
if vuf.dark then
    for _, v in next, {
        PlayerFrameTexture,
        TargetFrameTextureFrameTexture,
        TargetFrameToTTextureFrameTexture,
        FocusFrameTextureFrameTexture,
        FocusFrameToTTextureFrameTexture,
        PetFrameTexture,
--      PartyMemberFrame1Texture, 
--      PartyMemberFrame2Texture, 
--      PartyMemberFrame3Texture, 
--      PartyMemberFrame4Texture,
--	PartyMemberFrame1PetFrameTexture, 
--	PartyMemberFrame2PetFrameTexture, 
--	PartyMemberFrame3PetFrameTexture, 
--	PartyMemberFrame4PetFrameTexture, 
--	FocusFrameSpellBarBorder, 
--	TargetFrameSpellBarBorder, 
--	CastingBarFrameBorder,
    }
    do
        v:SetVertexColor(unpack(vuf.frameRgb))
    end
end


-- GOLD PALADIN
if vuf.gpal then
RAID_CLASS_COLORS["PALADIN"] = CreateColor(0.9, 0.75, 0, 1);
RAID_CLASS_COLORS["PALADIN"].colorStr = RAID_CLASS_COLORS["PALADIN"]:GenerateHexColor()
end


--BLUE SHAMAN
if vuf.bsham then
RAID_CLASS_COLORS["SHAMAN"] = CreateColor(0, 0.44, 0.87, 1);
RAID_CLASS_COLORS["SHAMAN"].colorStr = RAID_CLASS_COLORS["SHAMAN"]:GenerateHexColor()
end


-- GREEN DRUID
if vuf.gdru then
RAID_CLASS_COLORS["DRUID"] = CreateColor(0.2, 0.58, .5, 1);
RAID_CLASS_COLORS["DRUID"].colorStr = RAID_CLASS_COLORS["DRUID"]:GenerateHexColor()
end


-- CLASS ICON	
if vuf.ci or
( (select(2, UnitClass("player"))) == "DRUID" ) and vuf.cidruid or
( (select(2, UnitClass("player"))) == "HUNTER" ) and vuf.cihunter or
( (select(2, UnitClass("player"))) == "MAGE" ) and vuf.cimage or
( (select(2, UnitClass("player"))) == "PALADIN" ) and vuf.cipaladin or
( (select(2, UnitClass("player"))) == "PRIEST" ) and vuf.cipriest or
( (select(2, UnitClass("player"))) == "ROGUE" ) and vuf.cirogue or
( (select(2, UnitClass("player"))) == "SHAMAN" ) and vuf.cishaman or
( (select(2, UnitClass("player"))) == "WARLOCK" ) and vuf.ciwarlock or
( (select(2, UnitClass("player"))) == "WARRIOR" ) and vuf.ciwarrior then
    hooksecurefunc("UnitFramePortrait_Update",function(self)
        if self.portrait then
            if UnitIsPlayer(self.unit) then                         
                local t = CLASS_ICON_TCOORDS[select(2, UnitClass(self.unit))]
                    if t then
                        self.portrait:SetTexture("Interface\\TargetingFrame\\UI-Classes-Circles")
                        self.portrait:SetTexCoord(unpack(t))
                    end
            else
                       self.portrait:SetTexCoord(0,1,0,1)
            end
        end
    end)
end

